@@ -6,17 +6,15 @@
 
 #include "ExportMenu.h"
 #include "CaptureWindow.h"
+#include "SpectacleCore.h"
+#include "WidgetWindowUtils.h"
 #include "spectacle_gui_debug.h"
 #include "settings.h"
 
 #include <KApplicationTrader>
 #include <KIO/ApplicationLauncherJob>
 #include <kio_version.h>
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
 #include <KIO/JobUiDelegateFactory>
-#else
-#include <KIO/JobUiDelegate>
-#endif
 #include <KIO/OpenFileManagerWindowJob>
 #include <KIO/OpenUrlJob>
 #include <KLocalizedString>
@@ -25,6 +23,7 @@
 #include <KStandardShortcut>
 
 #include <QJsonArray>
+#include <QMimeDatabase>
 #include <QPrintDialog>
 #include <QPrinter>
 #include <QTimer>
@@ -32,15 +31,24 @@
 #include <chrono>
 
 using namespace std::chrono_literals;
+using namespace Qt::StringLiterals;
+
+class ExportMenuSingleton
+{
+public:
+    ExportMenu self;
+};
+
+Q_GLOBAL_STATIC(ExportMenuSingleton, privateExportMenuSelf)
 
 ExportMenu::ExportMenu(QWidget *parent)
     : SpectacleMenu(parent)
 #ifdef PURPOSE_FOUND
-    , mUpdatedImageAvailable(false)
-    , mPurposeMenu(new Purpose::Menu(this))
+    , mUpdatedImageAvailable(true)
+    , mPurposeMenu(new Purpose::Menu)
 #endif
 {
-    addAction(QIcon::fromTheme(QStringLiteral("document-open-folder")),
+    addAction(QIcon::fromTheme(u"document-open-folder"_s),
               i18n("Open Default Screenshots Folder"),
               this, &ExportMenu::openScreenshotsFolder);
     addAction(KStandardAction::print(this, &ExportMenu::openPrintDialog, this));
@@ -54,6 +62,11 @@ ExportMenu::ExportMenu(QWidget *parent)
     getKServiceItems();
 }
 
+ExportMenu *ExportMenu::instance()
+{
+    return &privateExportMenuSelf->self;
+}
+
 void ExportMenu::onImageChanged()
 {
 #ifdef PURPOSE_FOUND
@@ -68,22 +81,23 @@ void ExportMenu::getKServiceItems()
     // populate all locally installed applications and services
     // which can handle images first
 
-    const KService::List services = KApplicationTrader::queryByMimeType(QStringLiteral("image/png"));
+    const KService::List services = KApplicationTrader::queryByMimeType(u"image/png"_s);
 
     for (auto service : services) {
-        const QString name = service->name().replace(QLatin1Char('&'), QLatin1String("&&"));
+        const QString name = service->name().replace('&'_L1, "&&"_L1);
         QAction *action = new QAction(QIcon::fromTheme(service->icon()), name, this);
 
         connect(action, &QAction::triggered, this, [this, service]() {
-            auto captureWindow = qobject_cast<CaptureWindow *>(this->windowHandle()->transientParent());
+            auto captureWindow = qobject_cast<CaptureWindow *>(getWidgetTransientParent(this));
             if(captureWindow && !captureWindow->accept()) {
                 return;
             }
             QUrl filename;
             if(ExportManager::instance()->isImageSavedNotInTemp()) {
-                filename = Settings::self()->lastSaveLocation();
+                filename = Settings::self()->lastImageSaveLocation();
             } else {
                 filename = ExportManager::instance()->getAutosaveFilename();
+                SpectacleCore::instance()->syncExportImage();
                 ExportManager::instance()->exportImage(ExportManager::Save, filename);
             }
 
@@ -107,24 +121,21 @@ void ExportMenu::getKServiceItems()
     openWith->setShortcuts(KStandardShortcut::open());
 
     connect(openWith, &QAction::triggered, this, [this]() {
-        auto captureWindow = qobject_cast<CaptureWindow *>(this->windowHandle()->transientParent());
+        auto captureWindow = qobject_cast<CaptureWindow *>(getWidgetTransientParent(this));
         if(captureWindow && !captureWindow->accept()) {
             return;
         }
         QUrl filename;
         if(ExportManager::instance()->isImageSavedNotInTemp()) {
-            filename = Settings::self()->lastSaveLocation();
+            filename = Settings::self()->lastImageSaveLocation();
         } else {
             filename = ExportManager::instance()->getAutosaveFilename();
+            SpectacleCore::instance()->syncExportImage();
             ExportManager::instance()->exportImage(ExportManager::Save, filename);
         }
 
         auto job = new KIO::ApplicationLauncherJob;
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
         job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, window()));
-#else
-        job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, window()));
-#endif
         job->setUrls({filename});
         job->start();
     });
@@ -135,23 +146,25 @@ void ExportMenu::getKServiceItems()
 void ExportMenu::loadPurposeMenu()
 {
     // attach the menu
-    QAction *purposeMenu = addMenu(mPurposeMenu);
-    purposeMenu->setText(i18n("Share"));
-    purposeMenu->setIcon(QIcon::fromTheme(QStringLiteral("document-share")));
+    auto purposeMenu = mPurposeMenu.get();
+    QAction *purposeMenuAction = addMenu(purposeMenu);
+    purposeMenuAction->setObjectName("purposeMenuAction");
+    purposeMenuAction->setText(i18n("Share"));
+    purposeMenuAction->setIcon(QIcon::fromTheme(u"document-share"_s));
 
     // set up the callback signal
-    connect(mPurposeMenu, &Purpose::Menu::finished, this, [this](const QJsonObject &output, int error, const QString &message) {
+    connect(purposeMenu, &Purpose::Menu::finished, this, [this](const QJsonObject &output, int error, const QString &message) {
         if (error) {
             Q_EMIT imageShared(error, message);
         } else {
-            Q_EMIT imageShared(error, output[QStringLiteral("url")].toString());
+            Q_EMIT imageShared(error, output[u"url"_s].toString());
         }
     });
 
     // update available options based on the latest picture
-    connect(mPurposeMenu, &QMenu::aboutToShow, this, [this]() {
+    connect(purposeMenu, &QMenu::aboutToShow, this, [this]() {
         loadPurposeItems();
-        mPurposeMenu->windowHandle()->setTransientParent(windowHandle());
+        setWidgetTransientParentToWidget(mPurposeMenu.get(), this);
     });
 }
 
@@ -165,30 +178,27 @@ void ExportMenu::loadPurposeItems()
     const QString dataUri = ExportManager::instance()->tempSave().toString();
     mUpdatedImageAvailable = false;
 
+    auto mimeType = QMimeDatabase().mimeTypeForFile(dataUri).name();
     QJsonObject inputData = {
-        {QStringLiteral("mimeType"), QStringLiteral("image/png")},
-        {QStringLiteral("urls"), QJsonArray({dataUri})}
+        {u"mimeType"_s, mimeType},
+        {u"urls"_s, QJsonArray({dataUri})}
     };
     mPurposeMenu->model()->setInputData(inputData);
-    mPurposeMenu->model()->setPluginType(QStringLiteral("Export"));
+    mPurposeMenu->model()->setPluginType(u"Export"_s);
     mPurposeMenu->reload();
 }
 #endif
 
 void ExportMenu::openScreenshotsFolder()
 {
-    auto job = new KIO::OpenUrlJob(Settings::defaultSaveLocation());
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
+    auto job = new KIO::OpenUrlJob(Settings::imageSaveLocation());
     job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
-#else
-    job->setUiDelegate(new KIO::JobUiDelegate(KIO::JobUiDelegate::AutoHandlingEnabled, this));
-#endif
     job->start();
 }
 
 void ExportMenu::openPrintDialog()
 {
-    if (auto captureWindow = qobject_cast<CaptureWindow *>(windowHandle()->transientParent())) {
+    if (auto captureWindow = qobject_cast<CaptureWindow *>(getWidgetTransientParent(this))) {
         captureWindow->accept();
     }
     auto printer = new QPrinter(QPrinter::HighResolution);
@@ -196,9 +206,7 @@ void ExportMenu::openPrintDialog()
     dialog->setAttribute(Qt::WA_DeleteOnClose);
 
     // properly set the transientparent chain
-    if (dialog->winId()) {
-        dialog->windowHandle()->setTransientParent(windowHandle()->transientParent());
-    }
+    setWidgetTransientParent(dialog, getWidgetTransientParent(this));
 
     connect(dialog, &QDialog::finished, dialog, [printer](int result){
         if (result == QDialog::Accepted) {
@@ -209,3 +217,5 @@ void ExportMenu::openPrintDialog()
 
     dialog->setVisible(true);
 }
+
+#include "moc_ExportMenu.cpp"
