@@ -69,6 +69,8 @@ public:
      * This is meant to be used in QML.
      */
     Q_INVOKABLE qreal dprRound(qreal value) const;
+    Q_INVOKABLE qreal dprCeil(qreal value) const;
+    Q_INVOKABLE qreal dprFloor(qreal value) const;
 
     /**
      * Get the basename for a file URL.
