@@ -7,6 +7,7 @@
 #pragma once
 
 #include "Gui/SpectacleWindow.h"
+#include <QPalette>
 
 class ViewerWindowPrivate;
 
@@ -19,10 +20,6 @@ class ViewerWindowPrivate;
 class ViewerWindow : public SpectacleWindow
 {
     Q_OBJECT
-    // Only create this window after the image has been set
-    Q_PROPERTY(QSize imageSize READ imageSize NOTIFY imageSizeChanged FINAL)
-    Q_PROPERTY(qreal imageDpr READ imageDpr NOTIFY imageDprChanged FINAL)
-
 public:
     enum Mode {
         Dialog,
@@ -30,25 +27,21 @@ public:
         Video,
     };
 
-    using UniquePointer = std::unique_ptr<ViewerWindow, decltype(&SpectacleWindow::deleter)>;
+    using UniquePointer = std::unique_ptr<ViewerWindow, void (*)(ViewerWindow *)>;
 
     static UniquePointer makeUnique(Mode mode, QQmlEngine *engine, QWindow *parent = nullptr);
 
     static ViewerWindow *instance();
 
-    QSize imageSize() const;
-    qreal imageDpr() const;
-
-    void showSavedScreenshotMessage(const QUrl &messageArgument);
-    void showSavedVideoMessage(const QUrl &messageArgument);
+    void showSavedMessage(const QUrl &messageArgument, bool video = false);
     void showSavedAndCopiedMessage(const QUrl &messageArgument);
-    void showSavedAndLocationCopiedMessage(const QUrl &messageArgument);
+    void showSavedAndLocationCopiedMessage(const QUrl &messageArgument, bool video = false);
     void showCopiedMessage();
+    void showLocationCopiedMessage();
     void showScreenshotFailedMessage();
+    void showRecordingFailedMessage(const QString &messageArgument);
 
-Q_SIGNALS:
-    void imageSizeChanged();
-    void imageDprChanged();
+    Q_INVOKABLE void startDrag();
 
 protected:
     bool event(QEvent *event) override;
@@ -64,6 +57,7 @@ private:
     Q_SLOT void updateMinimumSize();
     Q_SLOT void showInlineMessage(const QString &source, const QVariantMap &properties);
     Q_SLOT void showImageSharedMessage(int errorCode, const QString &messageArgument);
+    void showVideoSharedMessage(int errorCode, const QString &messageArgument);
 
     void setBackgroundColorRole(QPalette::ColorRole role);
 
